@@ -2,12 +2,13 @@ if (!dir.exists(tempdir())) {
   dir.create(tempdir())
 }
 test_that("is.biosoftwares.db.active",{ 
-  db <- sprintf('%s/test', tempdir())
+  tmp.dir <- normalizePath(tempdir(), "/")
+  db <- sprintf('%s/test', tmp.dir)
+  db <- normalizePath(db, "/", mustWork = FALSE)
   x <- is.biosoftwares.db.active(db)
   expect_that(x, equals(FALSE))
   set.biosoftwares.db(db)
-  x <- is.biosoftwares.db.active(db)
+  x <- do.call(is.biosoftwares.db.active, list(db))
   expect_that(x, equals(TRUE))
+  unlink(db, recursive = TRUE, TRUE)
 })
-temps <- list.files(tempdir(), ".*")
-unlink(sprintf("%s/%s", tempdir(), temps), recursive = TRUE, TRUE)
